@@ -58,6 +58,13 @@ def register(group):
     show_default=True,
     type=click.INT,
 )
+@click.option(
+    "--role-name",
+    default=None,
+    help="The name of a pre-created execution role for the log ingest function",
+    metavar="<role_name>",
+    show_default=False,
+)
 def install(
     aws_profile,
     aws_region,
@@ -70,6 +77,7 @@ def install(
     nr_api_key,
     nr_region,
     timeout,
+    role_name,
 ):
     """Install New Relic AWS Lambda Integration"""
     session = boto3.Session(profile_name=aws_profile, region_name=aws_region)
@@ -106,7 +114,7 @@ def install(
 
     click.echo("Creating newrelic-log-ingestion Lambda function in AWS account")
     res = integrations.install_log_ingestion(
-        session, nr_license_key, enable_logs, memory_size, timeout
+        session, nr_license_key, enable_logs, memory_size, timeout, role_name
     )
     install_success = res and install_success
 
@@ -163,39 +171,38 @@ def uninstall(aws_profile, aws_region, aws_permissions_check, nr_account_id, for
 @add_options(AWS_OPTIONS)
 @click.option(
     "--enable-logs/--disable-logs",
-    default=False,
+    default=None,
     help="Determines if logs are forwarded to New Relic Logging",
-    show_default=True,
 )
 @click.option(
     "--memory-size",
     "-m",
-    default=128,
     help="Memory size (in MiB) for the log ingestion function",
     metavar="<size>",
-    show_default=True,
     type=click.INT,
 )
-@add_options(NR_OPTIONS)
 @click.option(
     "--timeout",
     "-t",
-    default=30,
     help="Timeout (in seconds) for the New Relic log ingestion function",
     metavar="<secs>",
-    show_default=True,
     type=click.INT,
 )
+@click.option(
+    "--role-name",
+    default=None,
+    help="The name of a new pre-created execution role for the log ingest function",
+    metavar="<role_name>",
+    show_default=False,
+)
 def update(
     aws_profile,
     aws_region,
     aws_permissions_check,
     enable_logs,
     memory_size,
-    nr_account_id,
-    nr_api_key,
-    nr_region,
     timeout,
+    role_name,
 ):
     """UpdateNew Relic AWS Lambda Integration"""
     session = boto3.Session(profile_name=aws_profile, region_name=aws_region)
@@ -203,17 +210,11 @@ def update(
     if aws_permissions_check:
         permissions.ensure_integration_install_permissions(session)
 
-    click.echo("Validating New Relic credentials")
-    gql_client = api.validate_gql_credentials(nr_account_id, nr_api_key, nr_region)
-
-    click.echo("Retrieving integration license key")
-    nr_license_key = api.retrieve_license_key(gql_client)
-
     update_success = True
 
     click.echo("Updating newrelic-log-ingestion Lambda function in AWS account")
     res = integrations.update_log_ingestion(
-        session, nr_license_key, enable_logs, memory_size, timeout
+        session, None, enable_logs, memory_size, timeout, role_name
     )
     update_success = res and update_success
 
